@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2011, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2011, 2024, Oracle and/or its affiliates. All rights reserved.
  * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
  *
  *
@@ -46,7 +46,6 @@ import java.awt.event.WindowStateListener;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 import java.lang.reflect.InvocationTargetException;
-import java.security.AccessController;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Comparator;
@@ -64,12 +63,12 @@ import sun.awt.AWTAccessor;
 import sun.awt.AWTAccessor.ComponentAccessor;
 import sun.awt.AWTAccessor.WindowAccessor;
 import sun.java2d.SurfaceData;
+import sun.lwawt.LWKeyboardFocusManagerPeer;
 import sun.lwawt.LWLightweightFramePeer;
 import sun.lwawt.LWToolkit;
 import sun.lwawt.LWWindowPeer;
 import sun.lwawt.LWWindowPeer.PeerType;
 import sun.lwawt.PlatformWindow;
-import sun.security.action.GetPropertyAction;
 import sun.util.logging.PlatformLogger;
 
 public class CPlatformWindow extends CFRetainedResource implements PlatformWindow {
@@ -130,9 +129,7 @@ public class CPlatformWindow extends CFRetainedResource implements PlatformWindo
 
     // This system property is named as jdk.* because it is not specific to AWT
     // and it is also used in JavaFX
-    @SuppressWarnings("removal")
-    public static final String MAC_OS_TABBED_WINDOW = AccessController.doPrivileged(
-            new GetPropertyAction("jdk.allowMacOSTabbedWindows"));
+    public static final String MAC_OS_TABBED_WINDOW = System.getProperty("jdk.allowMacOSTabbedWindows");
 
     // Yeah, I know. But it's easier to deal with ints from JNI
     static final int MODELESS = 0;
@@ -271,7 +268,6 @@ public class CPlatformWindow extends CFRetainedResource implements PlatformWindo
             }
         }
     }) {
-        @SuppressWarnings("deprecation")
         public CPlatformWindow convertJComponentToTarget(final JRootPane p) {
             Component root = SwingUtilities.getRoot(p);
             final ComponentAccessor acc = AWTAccessor.getComponentAccessor();
@@ -364,7 +360,7 @@ public class CPlatformWindow extends CFRetainedResource implements PlatformWindo
             }
         });
         setPtr(ref.get());
-        if (peer != null) { // Not applicable to CWarningWindow
+        if (peer != null) {
             peer.setTextured(IS(TEXTURED, styleBits));
         }
         if (target instanceof javax.swing.RootPaneContainer) {
@@ -667,6 +663,44 @@ public class CPlatformWindow extends CFRetainedResource implements PlatformWindo
             execute(CPlatformWindow::nativeSetNSWindowLocationByPlatform);
         }
 
+        // Manage the extended state when showing
+        if (visible) {
+                /* Frame or Dialog should be set property WINDOW_FULLSCREENABLE to true if the
+                Frame or Dialog is resizable.
+                */
+            final boolean resizable = (target instanceof Frame) ? ((Frame)target).isResizable() :
+                    ((target instanceof Dialog) ? ((Dialog)target).isResizable() : false);
+            if (resizable) {
+                setCanFullscreen(true);
+            }
+
+            // Apply the extended state as expected in shared code
+            if (target instanceof Frame) {
+                if (!wasMaximized && isMaximized()) {
+                    // setVisible could have changed the native maximized state
+                    deliverZoom(true);
+                } else {
+                    int frameState = ((Frame)target).getExtendedState();
+                    if ((frameState & Frame.ICONIFIED) != 0) {
+                        // Treat all state bit masks with ICONIFIED bit as ICONIFIED state.
+                        frameState = Frame.ICONIFIED;
+                    }
+
+                    switch (frameState) {
+                        case Frame.ICONIFIED:
+                            execute(CWrapper.NSWindow::miniaturize);
+                            break;
+                        case Frame.MAXIMIZED_BOTH:
+                            maximize();
+                            break;
+                        default: // NORMAL
+                            unmaximize(); // in case it was maximized, otherwise this is a no-op
+                            break;
+                    }
+                }
+            }
+        }
+
         // Actually show or hide the window
         LWWindowPeer blocker = (peer == null)? null : peer.getBlocker();
         if (blocker == null || !visible) {
@@ -727,44 +761,6 @@ public class CPlatformWindow extends CFRetainedResource implements PlatformWindo
         }
         this.visible = visible;
 
-        // Manage the extended state when showing
-        if (visible) {
-            /* Frame or Dialog should be set property WINDOW_FULLSCREENABLE to true if the
-            Frame or Dialog is resizable.
-            **/
-            final boolean resizable = (target instanceof Frame) ? ((Frame)target).isResizable() :
-            ((target instanceof Dialog) ? ((Dialog)target).isResizable() : false);
-            if (resizable) {
-                setCanFullscreen(true);
-            }
-
-            // Apply the extended state as expected in shared code
-            if (target instanceof Frame) {
-                if (!wasMaximized && isMaximized()) {
-                    // setVisible could have changed the native maximized state
-                    deliverZoom(true);
-                } else {
-                    int frameState = ((Frame)target).getExtendedState();
-                    if ((frameState & Frame.ICONIFIED) != 0) {
-                        // Treat all state bit masks with ICONIFIED bit as ICONIFIED state.
-                        frameState = Frame.ICONIFIED;
-                    }
-
-                    switch (frameState) {
-                        case Frame.ICONIFIED:
-                            execute(CWrapper.NSWindow::miniaturize);
-                            break;
-                        case Frame.MAXIMIZED_BOTH:
-                            maximize();
-                            break;
-                        default: // NORMAL
-                            unmaximize(); // in case it was maximized, otherwise this is a no-op
-                            break;
-                    }
-                }
-            }
-        }
-
         nativeSynthesizeMouseEnteredExitedEvents();
 
         // Configure stuff #2
@@ -1023,7 +1019,6 @@ public class CPlatformWindow extends CFRetainedResource implements PlatformWindo
                     // let's return into the normal states first
                     execute(CWrapper.NSWindow::deminiaturize);
                     waitForWindowState(Frame.NORMAL);
-
                 }
                 maximize();
                 break;
@@ -1057,6 +1052,11 @@ public class CPlatformWindow extends CFRetainedResource implements PlatformWindo
         }
 
         execute(ptr -> nativeSetEnabled(ptr, !blocked));
+
+        Window currFocus = LWKeyboardFocusManagerPeer.getInstance().getCurrentFocusedWindow();
+        if (!blocked && (target == currFocus)) {
+            requestWindowFocus();
+        }
         checkBlockingAndOrder();
     }
 
