@@ -460,7 +460,14 @@ public class FormatData_be extends ListResourceBundle {
             { "japanese.narrow.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_generic_TimePatterns },
             { "java.time.japanese.DatePatterns", metaValue_java_time_generic_DatePatterns },
-            { "japanese.DatePatterns", metaValue_generic_DatePatterns },
+            { "japanese.DatePatterns",
+                new String[] {
+                    "EEEE, d MMMM yyyy GGGG",
+                    "d MMMM yyyy GGGG",
+                    "d.M.y GGGG",
+                    "d.M.y G",
+                }
+            },
             { "japanese.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
             { "japanese.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
             { "japanese.DateFormatItem.Ehms", metaValue_generic_DateFormatItem_Ehms },
