@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2024, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
  * ORACLE PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
  */
 
@@ -271,7 +271,14 @@ public class FormatData_bo extends ListResourceBundle {
             { "japanese.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_generic_TimePatterns },
             { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "japanese.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "japanese.DatePatterns",
+                new String[] {
+                    "",
+                    "GGGG \u0f66\u0fa4\u0fb1\u0f72\u0f0b\u0f63\u0f7c\u0f0byyyy MMMM\u0f60\u0f72\u0f0b\u0f5a\u0f7a\u0f66\u0f0bd",
+                    "GGGG y \u0f63\u0f7c\u0f60\u0f72\u0f0bMMM\u0f5a\u0f7a\u0f66\u0f0bd",
+                    "",
+                }
+            },
             { "japanese.DateFormatItem.yMMMMd", metaValue_generic_DateFormatItem_yMMMMd },
             { "japanese.DateFormatItem.yMMMd", metaValue_generic_DateFormatItem_yMMMd },
             { "japanese.DateFormatItem.yMMM", metaValue_generic_DateFormatItem_yMMM },
